Disinfect: Destroy bad input.
==================================================================

.. begin

Disinfect allows you to validate and sanitize incoming data.

* Free software: MIT license
* Documentation: http://pythonhosted.org/disinfect

A quick example::

    # todo


Features
--------

* TODO

Authors
-------

``Disinfect`` is written and maintained by
`Nils Corver <nils@corverdevelopment.nl>`_.

A full list of contributors can be found in
`GitHub's overview <https://github.com/corverdevelopment/disinfect/graphs/contributors>`_.
